Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(394)

Unified Diff: content/browser/renderer_host/buffered_resource_handler.cc

Issue 10568005: Balance defers with Resume. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 6 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/browser/renderer_host/buffered_resource_handler.cc
===================================================================
--- content/browser/renderer_host/buffered_resource_handler.cc (revision 142108)
+++ content/browser/renderer_host/buffered_resource_handler.cc (working copy)
@@ -387,12 +387,14 @@
net::URLRequestStatus status(net::URLRequestStatus::HANDLED_EXTERNALLY, 0);
next_handler_->OnResponseCompleted(request_id, status, std::string());
// Remove the non-owning pointer to the CrossSiteResourceHandler, if any,
// from the extra request info because the CrossSiteResourceHandler (part of
// the original ResourceHandler chain) will be deleted by the next statement.
ResourceRequestInfoImpl* info =
ResourceRequestInfoImpl::ForRequest(request_);
info->set_cross_site_handler(NULL);
+ info->set_async_handler(NULL);
// This is handled entirely within the new ResourceHandler, so just reset the
// original ResourceHandler.
« no previous file with comments | « content/browser/renderer_host/async_resource_handler.cc ('k') | content/browser/renderer_host/cross_site_resource_handler.h » ('j') | no next file with comments »
@@ -387,12 +387,14 @@
net::URLRequestStatus status(net::URLRequestStatus::HANDLED_EXTERNALLY, 0);
next_handler_->OnResponseCompleted(request_id, status, std::string());
- // Remove the non-owning pointer to the CrossSiteResourceHandler, if any,
- // from the extra request info because the CrossSiteResourceHandler (part of
- // the original ResourceHandler chain) will be deleted by the next statement.
+ // Remove the non-owning pointer to the {Async,CrossSite}ResourceHandler, if
+ // any, from the request info because the {Async,CrossSite}ResourceHandler
+ // (part of the original ResourceHandler chain) will be deleted by the next
+ // statement.
ResourceRequestInfoImpl* info =
ResourceRequestInfoImpl::ForRequest(request_);

Powered by Google App Engine
This is Rietveld 408576698